/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg;
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg {
NI32 module;
NI32 item;
};
struct tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA {
  RootObj Sup;
tyObject_ItemId__wg9aowaxscbUe2F0nV9btZLg itemId;
};
typedef NU8 tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw;
typedef NU16 tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag;
typedef NU64 tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA;
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU8 tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw;
typedef NU8 tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ;
typedef NU16 tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw;
struct tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw {
tyEnum_TLocKind__pD6N6rEUmrrqJbKE02Sezw k;
tyEnum_TStorageLoc__JIS9cieRcL9cZccyO9bM9aBmFQ storage;
tySet_tyEnum_TLocFlag__Ic4ywZl9cdJtKSUkG4WZfHw flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* lode;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* r;
};
struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw {
  tyObject_TIdObj__1qw9bcK4rZXhGbJEJhkKQFA Sup;
tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw kind;
union{
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* gcUnsafetyReason;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* transformedBody;
} _kind_1;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* guard;
NI bitsize;
NI alignment;
} _kind_2;
};
tyEnum_TMagic__3qAy6bDUDlF8Fc2RR6pF9ag magic;
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* name;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* owner;
tySet_tyEnum_TSymFlag__9be9c6fEXk5NwyPvxxb6toPA flags;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* ast;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
NI position;
NI offset;
tyObject_TLoc__CAJV4zTUpZwr0j6Wy8FiFw loc;
tyObject_TLib__W49cDqPTe2Tvc1mw7CVZOFg* annex;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* constraint;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NimStringDesc* tyArray__9bQBkVd2XTswDuOAXOSDFOA[42];
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differs__linter_138)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* newName);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__msgs_1111)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw i);
N_LIB_PRIVATE N_NIMCALL(NI, identLen__linter_13)(NimStringDesc* line, NI start);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differ__linter_76)(NimStringDesc* line, NI a, NI b, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__linter_82)(NimStringDesc* s, NI pos, NI last, NimStringDesc* substr);
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, addDeclaredLoc__astmsgs_17)(NimStringDesc** result, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, beautifyName__linter_33)(NimStringDesc* s, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, allCharsInSet__pureZstrutils_1341)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw theSet);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___linter_25)(NimStringDesc* s, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToUpperAsciiChar)(NIM_CHAR c);
static N_INLINE(NIM_BOOL, contains__pureZos_651)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__pureZos_656)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw Letters__linter_12 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x03,
0xfe, 0xff, 0xff, 0x87, 0xfe, 0xff, 0xff, 0x07,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff}
;
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_2, "\'$1\' should be: \'$2\'$3", 22);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_4, "/home/runner/work/nightlies/nightlies/nim/compiler/linter.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__u5vWF9bq7M9bLavMQS4OjP4A_3 = {((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_4),
((NI) 133),
((NI) 14)}
;
extern TNimType NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__u5vWF9bq7M9bLavMQS4OjP4A_5 = {((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_4),
((NI) 148),
((NI) 14)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__u5vWF9bq7M9bLavMQS4OjP4A_6 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x03,
0xfe, 0xff, 0xff, 0x87, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_8, "int", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_9, "uint", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_10, "cint", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_11, "cuint", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_12, "clong", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_13, "cstring", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_14, "string", 6);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_15, "char", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_16, "byte", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_17, "bool", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_18, "openArray", 9);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_19, "seq", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_20, "array", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_21, "void", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_22, "pointer", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_23, "float", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_24, "csize", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_25, "csize_t", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_26, "cdouble", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_27, "cchar", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_28, "cschar", 6);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_29, "cshort", 6);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_30, "cu", 2);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_31, "nil", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_32, "typedesc", 8);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_33, "auto", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_34, "any", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_35, "range", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_36, "openarray", 9);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_37, "varargs", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_38, "set", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_39, "cfloat", 6);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_40, "ref", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_41, "ptr", 3);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_42, "untyped", 7);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_43, "typed", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_44, "static", 6);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_45, "sink", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_46, "lent", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_47, "type", 4);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_48, "owned", 5);
STRING_LITERAL(TM__u5vWF9bq7M9bLavMQS4OjP4A_49, "iterable", 8);
static NIM_CONST tyArray__9bQBkVd2XTswDuOAXOSDFOA TM__u5vWF9bq7M9bLavMQS4OjP4A_7 = {((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_8),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_9),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_10),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_11),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_12),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_13),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_14),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_15),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_16),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_17),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_18),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_19),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_20),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_21),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_22),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_23),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_24),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_25),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_26),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_27),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_28),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_29),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_30),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_31),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_32),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_33),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_34),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_35),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_36),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_37),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_38),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_39),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_40),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_41),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_42),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_43),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_44),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_45),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_46),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_47),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_48),
((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_49)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__u5vWF9bq7M9bLavMQS4OjP4A_50 = {((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_4),
((NI) 91),
((NI) 14)}
;
N_LIB_PRIVATE N_NIMCALL(NI, identLen__linter_13)(NimStringDesc* line, NI start) {
	NI result;
	result = (NI)0;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((NI)(start + result) < (line ? line->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = (((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(97)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(122)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(65)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(90)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(48)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(57)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(128)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(255)) || ((NU8)(line->data[(NI)(start + result)])) == ((NU8)(95)));
			LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI) 1);
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__linter_82)(NimStringDesc* s, NI pos, NI last, NimStringDesc* substr) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (substr ? substr->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = (last < (NI)(pos + i));
					if (T6_) goto LA7_;
					T6_ = !(((NU8)(s->data[(NI)(pos + i)]) == (NU8)(substr->data[i])));
					LA7_: ;
					if (!T6_) goto LA8_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___pureZunicode_865)(NimStringDesc* s, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = NIM_NIL;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw, dotdot___pureZunicode_840)(NI a, NI b) {
	tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differ__linter_76)(NimStringDesc* line, NI a, NI b, NimStringDesc* x) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T3_;
		NimStringDesc* y;
		tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = substrEq__linter_82(line, a, b, x);
		if (!!(T3_)) goto LA4_;
		T6_ = dotdot___pureZunicode_840(a, b);
		y = X5BX5D___pureZunicode_865(line, T6_);
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = nsuCmpIgnoreStyle(y, x);
			if (!(T9_ == ((NI) 0))) goto LA10_;
			result = copyString(y);
		}
		LA10_: ;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differs__linter_138)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* newName) {
	NimStringDesc* result;
	NimStringDesc* line;
	NI first;
	NI last;
	NI T19_;
{	result = NIM_NIL;
	line = sourceLine__msgs_1111(conf, info);
	first = ((((NI) (info.col)) <= (line ? line->Sup.len : 0)) ? ((NI) (info.col)) : (line ? line->Sup.len : 0));
	{
		if (!(first < ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		while (1) {
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((NI) 0) < first);
			if (!(T7_)) goto LA8_;
			T7_ = (((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(97)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(122)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(65)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(90)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(48)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(57)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(128)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(255)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) == ((NU8)(95)));
			LA8_: ;
			if (!T7_) goto LA6;
			first -= ((NI) 1);
		} LA6: ;
	}
	{
		if (!(first < ((NI) 0))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((NI)(first + ((NI) 1)) < (line ? line->Sup.len : 0));
		if (!(T15_)) goto LA16_;
		T15_ = ((NU8)(line->data[first]) == (NU8)(96));
		LA16_: ;
		if (!T15_) goto LA17_;
		first += ((NI) 1);
	}
	LA17_: ;
	T19_ = (NI)0;
	T19_ = identLen__linter_13(line, first);
	last = (NI)((NI)(first + T19_) - ((NI) 1));
	result = differ__linter_76(line, first, last, newName);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUseImpl__linter_158)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s) {
	NimStringDesc* newName;
	NimStringDesc* badName;
	newName = (*(*s).name).s;
	badName = differs__linter_138(conf, info, newName);
	{
		NimStringDesc* mX60gensym15_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T5_;
		NimStringDesc* dupResult;
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msgX60gensym15_;
		if (!(((NI) 0) < (badName ? badName->Sup.len : 0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T5_[0] = copyString(badName);
		T5_[1] = copyString(newName);
		dupResult = ((NimStringDesc*) NIM_NIL);
		addDeclaredLoc__astmsgs_17((&dupResult), conf, s);
		T5_[2] = copyString(dupResult);
		mX60gensym15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_2), T5_, 3);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 15))&63U)))!=0)) goto LA8_;
			msgX60gensym15_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15);
		}
		goto LA6_;
		LA8_: ;
		{
			msgX60gensym15_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 91);
		}
		LA6_: ;
		liMessage__msgs_1128(conf, info, msgX60gensym15_, mX60gensym15_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__u5vWF9bq7M9bLavMQS4OjP4A_3, NIM_FALSE);
	}
	LA3_: ;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUseImpl__linter_197)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw w, NimStringDesc* pragmaName) {
	NimStringDesc* wanted;
	wanted = reprEnum((NI)w, (&NTItspecialword__N2XsqTpO5IzOf2KmXwk4Dw_));
	{
		NimStringDesc* mX60gensym19_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T5_;
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msgX60gensym19_;
		if (!!(eqStrings(pragmaName, wanted))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T5_[0] = copyString(pragmaName);
		T5_[1] = copyString(wanted);
		T5_[2] = ((NimStringDesc*) NIM_NIL);
		mX60gensym19_ = nsuFormatOpenArray(((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_2), T5_, 3);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 15))&63U)))!=0)) goto LA8_;
			msgX60gensym19_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15);
		}
		goto LA6_;
		LA8_: ;
		{
			msgX60gensym19_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 91);
		}
		LA6_: ;
		liMessage__msgs_1128(conf, info, msgX60gensym19_, mX60gensym19_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__u5vWF9bq7M9bLavMQS4OjP4A_5, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___linter_25)(NimStringDesc* s, NimStringDesc** a, NI aLen_0) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NimStringDesc** x;
		NI i;
		x = (NimStringDesc**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < aLen_0)) goto LA3;
				x = (&a[i]);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = nsuStartsWith(s, (*x));
					if (!T6_) goto LA7_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__pureZos_656)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__pureZos_651)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__pureZos_656(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, beautifyName__linter_33)(NimStringDesc* s, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k) {
	NimStringDesc* result;
	NIM_BOOL allUpper;
	NI i;
{	result = NIM_NIL;
	allUpper = allCharsInSet__pureZstrutils_1341(s, TM__u5vWF9bq7M9bLavMQS4OjP4A_6);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = allUpper;
		if (!(T3_)) goto LA4_;
		T3_ = ((1049728 &((NU32)1<<((NU)(k)&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = copyString(s);
		goto BeforeRet_;
	}
	LA5_: ;
	result = rawNewString(((NI) ((s ? s->Sup.len : 0))));
	i = ((NI) 0);
	switch (k) {
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 7):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 4):
	{
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = eqtilde___linter_25(s, TM__u5vWF9bq7M9bLavMQS4OjP4A_7, 42);
			if (!T10_) goto LA11_;
			result = addChar(result, s->data[i]);
		}
		goto LA8_;
		LA11_: ;
		{
			NIM_CHAR T14_;
			T14_ = (NIM_CHAR)0;
			T14_ = nsuToUpperAsciiChar(s->data[i]);
			result = addChar(result, T14_);
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 10):
	case ((tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw) 20):
	{
		result = addChar(result, s->data[((NI) 0)]);
	}
	break;
	default:
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((s ? s->Sup.len : 0) == ((NI) 1));
			if (!(T19_)) goto LA20_;
			T19_ = ((NU8)(s->data[((NI) 0)]) == (NU8)(76));
			LA20_: ;
			if (!T19_) goto LA21_;
			result = addChar(result, 76);
		}
		goto LA17_;
		LA21_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = contains__pureZos_651((s) ? (s->data) : NIM_NIL, (s ? s->Sup.len : 0), 95);
			if (!T24_) goto LA25_;
			result = addChar(result, s->data[i]);
		}
		goto LA17_;
		LA25_: ;
		{
			NIM_CHAR T28_;
			T28_ = (NIM_CHAR)0;
			T28_ = nsuToLowerAsciiChar(s->data[((NI) 0)]);
			result = addChar(result, T28_);
		}
		LA17_: ;
	}
	break;
	}
	i += ((NI) 1);
	{
		while (1) {
			if (!(i < (s ? s->Sup.len : 0))) goto LA30;
			{
				if (!((NU8)(s->data[i]) == (NU8)(95))) goto LA33_;
				{
					if (!((s ? s->Sup.len : 0) <= (NI)(i + ((NI) 1)))) goto LA37_;
				}
				goto LA35_;
				LA37_: ;
				{
					NIM_BOOL T40_;
					T40_ = (NIM_BOOL)0;
					T40_ = (((NI) 0) < i);
					if (!(T40_)) goto LA41_;
					T40_ = (((NU8)(s->data[(NI)(i - ((NI) 1))])) >= ((NU8)(65)) && ((NU8)(s->data[(NI)(i - ((NI) 1))])) <= ((NU8)(90)));
					LA41_: ;
					if (!T40_) goto LA42_;
					result = addChar(result, 95);
					i += ((NI) 1);
					result = addChar(result, s->data[i]);
				}
				goto LA35_;
				LA42_: ;
				{
					NIM_CHAR T45_;
					i += ((NI) 1);
					T45_ = (NIM_CHAR)0;
					T45_ = nsuToUpperAsciiChar(s->data[i]);
					result = addChar(result, T45_);
				}
				LA35_: ;
			}
			goto LA31_;
			LA33_: ;
			{
				NIM_CHAR T49_;
				if (!allUpper) goto LA47_;
				T49_ = (NIM_CHAR)0;
				T49_ = nsuToLowerAsciiChar(s->data[i]);
				result = addChar(result, T49_);
			}
			goto LA31_;
			LA47_: ;
			{
				result = addChar(result, s->data[i]);
			}
			LA31_: ;
			i += ((NI) 1);
		} LA30: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__linter_112)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* s, tyEnum_TSymKind__sjiB9b9aO1FRPetW6gPYZbfw k) {
	NimStringDesc* beau;
	beau = beautifyName__linter_33((*(*s).name).s, k);
	{
		NimStringDesc* mX60gensym9_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T5_;
		tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msgX60gensym9_;
		if (!!(eqStrings((*(*s).name).s, beau))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T5_[0] = copyString((*(*s).name).s);
		T5_[1] = copyString(beau);
		T5_[2] = ((NimStringDesc*) NIM_NIL);
		mX60gensym9_ = nsuFormatOpenArray(((NimStringDesc*) &TM__u5vWF9bq7M9bLavMQS4OjP4A_2), T5_, 3);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 15))&63U)))!=0)) goto LA8_;
			msgX60gensym9_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15);
		}
		goto LA6_;
		LA8_: ;
		{
			msgX60gensym9_ = ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 91);
		}
		LA6_: ;
		liMessage__msgs_1128(conf, info, msgX60gensym9_, mX60gensym9_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__u5vWF9bq7M9bLavMQS4OjP4A_50, NIM_FALSE);
	}
	LA3_: ;
}
